@@ -4,6 +4,8 @@ from types import MappingProxyType
 from typing import TYPE_CHECKING, ClassVar, Dict, List, Type
 from unittest import mock
 
+from httpcore import AsyncIteratorByteStream, IteratorByteStream
+
 from .models import PassThrough, decode_request, encode_response
 from .transports import MockTransport, TryTransport
 
@@ -49,6 +51,21 @@ class Mocker(ABC):
             return True
         return False
 
+    @classmethod
+    def add_targets(cls, *targets: str) -> None:
+        targets = tuple(filter(lambda t: t not in cls.targets, targets))
+        if targets:
+            cls.targets.extend(targets)
+            cls.restart()
+
+    @classmethod
+    def remove_targets(cls, *targets: str) -> None:
+        targets = tuple(filter(lambda t: t in cls.targets, targets))
+        if targets:
+            for target in targets:
+                cls.targets.remove(target)
+            cls.restart()
+
     @classmethod
     def start(cls) -> None:
         # Ensure we only patch once!
@@ -67,9 +84,9 @@ class Mocker(ABC):
                     pass
 
     @classmethod
-    def stop(cls) -> None:
+    def stop(cls, force: bool = False) -> None:
         # Ensure we don't stop patching when registered transports exists
-        if cls.routers:
+        if cls.routers and not force:
             return
 
         # Stop patching HTTPX
@@ -77,6 +94,13 @@ class Mocker(ABC):
             patch = cls._patches.pop()
             patch.stop()
 
+    @classmethod
+    def restart(cls) -> None:
+        # Only stop and start if started
+        if cls._patches:  # pragma: nocover
+            cls.stop(force=True)
+            cls.start()
+
     @classmethod
     def handler(cls, httpx_request):
         httpx_response = None
@@ -128,6 +152,8 @@ class AbstractRequestMocker(Mocker):
             request = cls.to_httpx_request(**kwargs)
             request, kwargs = cls.prepare(request, **kwargs)
             response = cls._send(request, instance=self, target_spec=spec, **kwargs)
+            status_code, headers, stream, extensions = response
+            response = (status_code, headers, IteratorByteStream(stream), extensions)
             return response
 
         async def amock(self, *args, **kwargs):
@@ -137,6 +163,13 @@ class AbstractRequestMocker(Mocker):
             response = cls._send(request, instance=self, target_spec=spec, **kwargs)
             if inspect.isawaitable(response):
                 response = await response
+            status_code, headers, stream, extensions = response
+            response = (
+                status_code,
+                headers,
+                AsyncIteratorByteStream(stream),
+                extensions,
+            )
             return response
 
         return amock if inspect.iscoroutinefunction(spec) else mock
@@ -144,7 +177,11 @@ class AbstractRequestMocker(Mocker):
     @classmethod
     def _merge_args_and_kwargs(cls, argspec, args, kwargs):
         arg_names = argspec.args[1:]  # Skip self
-        new_kwargs = dict(zip(arg_names[-len(argspec.defaults) :], argspec.defaults))
+        new_kwargs = (
+            dict(zip(arg_names[-len(argspec.defaults) :], argspec.defaults))
+            if argspec.defaults
+            else dict()
+        )
         new_kwargs.update(zip(arg_names, args))
         new_kwargs.update(kwargs)
         return new_kwargs
@@ -193,10 +230,8 @@ class HTTPCoreMocker(AbstractRequestMocker):
         "httpcore._async.connection.AsyncHTTPConnection",
         "httpcore._async.connection_pool.AsyncConnectionPool",
         "httpcore._async.http_proxy.AsyncHTTPProxy",
-        "httpx._transports.asgi.ASGITransport",
-        "httpx._transports.wsgi.WSGITransport",
     ]
-    target_methods = ["request", "arequest"]
+    target_methods = ["handle_request", "handle_async_request"]
 
     @classmethod
     def prepare(cls, httpx_request, **kwargs):
@@ -221,7 +256,12 @@ class HTTPCoreMocker(AbstractRequestMocker):
         """
         Create a `HTTPX` request from transport request args.
         """
-        request = (kwargs["method"], kwargs["url"], kwargs["headers"], kwargs["stream"])
+        request = (
+            kwargs["method"],
+            kwargs["url"],
+            kwargs.get("headers"),
+            kwargs.get("stream"),
+        )
         httpx_request = decode_request(request)
         return httpx_request
 
