@@ -2,6 +2,7 @@ from typing import (
     Any,
     Callable,
     Dict,
+    Iterable,
     Iterator,
     List,
     NamedTuple,
@@ -44,7 +45,7 @@ def encode_response(response: httpx.Response) -> Response:
         response.status_code,
         response.headers.raw,
         response.stream,
-        response.ext,
+        response.extensions,
     )
 
 
@@ -57,9 +58,10 @@ def clone_response(response: httpx.Response, request: httpx.Request) -> httpx.Re
         headers=response.headers,
         stream=response.stream,
         request=request,
-        ext=dict(response.ext),
+        extensions=dict(response.extensions),
     )
-    response.read()
+    if isinstance(response.stream, Iterable):
+        response.read()  # Pre-read stream for easier call stats usage
     return response
 
 
@@ -99,8 +101,10 @@ class MockResponse(httpx.Response):
         http_version: Optional[str] = None,
         **kwargs: Any,
     ) -> None:
-        if callable(content) or isinstance(content, (dict, Exception)):  # type: ignore
-            raise ValueError(
+        if not isinstance(content, (str, bytes)) and (
+            callable(content) or isinstance(content, (dict, Exception))
+        ):
+            raise TypeError(
                 f"MockResponse content can only be str, bytes or byte stream"
                 f"got {content!r}. Please use json=... or side effects."
             )
@@ -110,7 +114,7 @@ class MockResponse(httpx.Response):
         if content_type:
             self.headers["Content-Type"] = content_type
         if http_version:
-            self.ext["http_version"] = http_version
+            self.extensions["http_version"] = http_version.encode("ascii")
 
 
 class Route:
@@ -153,7 +157,7 @@ class Route:
             self.return_value = response
 
         else:
-            raise ValueError(
+            raise TypeError(
                 f"Route can only % with int, dict or Response, got {response!r}"
             )
 
@@ -181,6 +185,8 @@ class Route:
 
     @return_value.setter
     def return_value(self, return_value: Optional[httpx.Response]) -> None:
+        if return_value is not None and not isinstance(return_value, httpx.Response):
+            raise TypeError(f"{return_value!r} is not an instance of httpx.Response")
         self.pass_through(False)
         self._return_value = return_value
 
@@ -312,7 +318,7 @@ class Route:
 
         # Validate result
         if result and not isinstance(result, (httpx.Response, httpx.Request)):
-            raise ValueError(
+            raise TypeError(
                 f"Side effects must return; either a `httpx.Response`,"
                 f"a `httpx.Request` for pass-through, "
                 f"or `None` for a non-match. Got {result!r}"
@@ -336,7 +342,7 @@ class Route:
                 self,
                 origin=(
                     Error("Mock Error", request=request)
-                    if issubclass(Error, httpx.HTTPError)
+                    if issubclass(Error, httpx.RequestError)
                     else Error()
                 ),
             )
